.. _part:modules:

=================================
:mod:`fipy` Package Documentation
=================================


.. toctree::
   :maxdepth: 1

   tutorial/index

.. autosummary::
   :toctree: generated
   :recursive:

   fipy
   examples
